==> netjsonconfig-0.1b0-py2.py3-none-any.whl: netjsonconfig/backends/openwrt/schema.py <==
"""
OpenWrt specific JSON-Schema definition
"""
from .timezones import timezones
from ...schema import schema as default_schema
from ...utils import merge_dict

schema = merge_dict(default_schema, {
    "properties": {
        "general": {
            "properties": {
                "timezone": {
                    "id": "timezone",
                    "type": "string",
                    "default": "Coordinated Universal Time",
                    "enum": list(timezones.keys())
                }
            }
        },
        "radios": {
            "items": {
                "properties": {
                    "driver": {
                        "id": "driver",
                        "type": "string",
                        "enum": [
                            "mac80211",
                            "ath5k",
                            "ath9k",
                            "broadcom"
                        ]
                    },
                    "protocol": {
                        "id": "protocol",
                        "type": "string",
                        "enum": [
                            "802.11a",
                            "802.11b",
                            "802.11g",
                            "802.11n",
                            "802.11ac"
                        ]
                    }
                }
            }
        },
        "ntp": {
            "id": "ntp",
            "type": "object",
            "title": "ntp settings",
            "additionalProperties": True,
            "properties": {
                "enabled": {
                    "id": "enabled",
                    "type": "boolean"
                },
                "enable_server": {
                    "id": "enable_server",
                    "type": "boolean"
                },
                "server": {
                    "id": "server",
                    "type": "array"
                }
            }
        },
        "ip_rules": {
            "id": "ip_rules",
            "type": "array",
            "title": "Ip rules",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Ip rule",
                "additionalProperties": True,
                "properties": {
                    "in": {
                        "id": "in",
                        "type": "string"
                    },
                    "out": {
                        "id": "out",
                        "type": "string"
                    },
                    "src": {
                        "id": "src",
                        "type": "string"
                    },
                    "dest": {
                        "id": "dest",
                        "type": "string"
                    },
                    "tos": {
                        "id": "tos",
                        "type": "integer"
                    },
                    "mark": {
                        "id": "mark",
                        "type": "string"
                    },
                    "invert": {
                        "id": "invert",
                        "type": "boolean",
                        "default": False
                    },
                    "lookup": {
                        "id": "invert",
                        "type": "string"
                    },
                    "goto": {
                        "id": "goto",
                        "type": "integer"
                    },
                    "action": {
                        "id": "action",
                        "type": "string",
                        "enum": [
                            "prohibit",
                            "unreachable",
                            "blackhole",
                            "throw"
                        ]
                    }
                }
            }
        },
        "led": {
            "id": "led",
            "type": "array",
            "title": "LED config",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "LED",
                "additionalProperties": True,
                "required": [
                    "name",
                    "sysfs",
                    "trigger"
                ],
                "properties": {
                    "name": {
                        "id": "name",
                        "type": "string"
                    },
                    "default": {
                        "id": "default",
                        "type": "boolean"
                    },
                    "dev": {
                        "id": "dev",
                        "type": "string"
                    },
                    "sysfs": {
                        "id": "sysfs",
                        "type": "string"
                    },
                    "trigger": {
                        "id": "trigger",
                        "type": "string"
                    },
                    "delayoff": {
                        "id": "delayoff",
                        "type": "integer"
                    },
                    "delayon": {
                        "id": "delayon",
                        "type": "integer"
                    },
                    "interval": {
                        "id": "interval",
                        "type": "integer"
                    },
                    "message": {
                        "id": "message",
                        "type": "string"
                    },
                    "mode": {
                        "id": "mode",
                        "type": "string"
                    }
                }
            }
        },
        "switch": {
            "id": "switch",
            "type": "array",
            "title": "VLANs",
            "uniqueItems": True,
            "additionalItems": True,
            "title": "Programmable Switch",
            "items": {
                "type": "object",
                "additionalProperties": True,
                "required": [
                    "name",
                    "reset",
                    "enable_vlan",
                    "vlan"
                ],
                "properties": {
                    "name": {
                        "id": "name",
                        "type": "string"
                    },
                    "reset": {
                        "id": "reset",
                        "type": "boolean"
                    },
                    "enable_vlan": {
                        "id": "enable_vlan",
                        "type": "boolean"
                    },
                    "vlan": {
                        "id": "vlan",
                        "type": "array",
                        "title": "VLANs",
                        "uniqueItems": True,
                        "additionalItems": True,
                        "items": {
                            "type": "object",
                            "title": "VLAN",
                            "additionalProperties": True,
                            "required": [
                                "device",
                                "vlan",
                                "ports"
                            ],
                            "properties": {
                                "device": {
                                    "id": "device",
                                    "type": "string"
                                },
                                "vlan": {
                                    "id": "vlan",
                                    "type": "integer"
                                },
                                "ports": {
                                    "id": "ports",
                                    "type": "string"
                                }
                            }
                        }
                    }
                }
            }
        }
    }
})

# add interface protos
schema['properties']['interfaces']['items']['properties']\
      ['addresses']['items']['properties']['proto']['enum'] += [
    'dhcpv6',
    'ppp',
    'pppoe',
    'pppoa',
    '3g',
    'qmi',
    'ncm',
    'hnet',
    'pptp',
    '6in4',
    'aiccu',
    '6to4',
    '6rd',
    'dslite',
    'l2tp',
    'relay',
    'gre',
    'gretap',
    'grev6',
    'grev6tap'
]

# mark driver and protocol as required
schema['properties']['radios']['items']['required'] += [
    'driver',
    'protocol'
]

==> netjsonconfig-0.2-py2.py3-none-any.whl: netjsonconfig/backends/openwrt/schema.py <==
"""
OpenWrt specific JSON-Schema definition
"""
from .timezones import timezones
from ...schema import schema as default_schema
from ...utils import merge_config

schema = merge_config(default_schema, {
    "definitions": {
        "interface_settings": {
            "properties": {
                "network": {
                    "type": "string",
                    "maxLength": 9,
                    "pattern": "^[a-zA-z0-9_]*$"
                },
                "addresses": {
                    "items": {
                        "properties": {
                            "proto": {
                                "enum": [
                                    'dhcpv6',
                                    'ppp',
                                    'pppoe',
                                    'pppoa',
                                    '3g',
                                    'qmi',
                                    'ncm',
                                    'hnet',
                                    'pptp',
                                    '6in4',
                                    'aiccu',
                                    '6to4',
                                    '6rd',
                                    'dslite',
                                    'l2tp',
                                    'relay',
                                    'gre',
                                    'gretap',
                                    'grev6',
                                    'grev6tap',
                                    'none'
                                ]
                            }
                        }
                    }
                }
            }
        },
        "wireless_interface": {
            "properties": {
                "wireless": {
                    "properties": {
                        "network": {
                            "type": "array",
                            "uniqueItems": True,
                            "additionalItems": True,
                            "minItems": 1,
                            "items": {
                                "type": "string"
                            }
                        }
                    }
                }
            }
        }
    },
    "properties": {
        "general": {
            "properties": {
                "timezone": {
                    "type": "string",
                    "default": "Coordinated Universal Time",
                    "enum": list(timezones.keys())
                }
            }
        },
        "radios": {
            "items": {
                "required": [
                    "driver",
                    "protocol"
                ],
                "properties": {
                    "driver": {
                        "type": "string",
                        "enum": [
                            "mac80211",
                            "ath5k",
                            "ath9k",
                            "broadcom"
                        ]
                    },
                    "protocol": {
                        "type": "string",
                        "enum": [
                            "802.11a",
                            "802.11b",
                            "802.11g",
                            "802.11n",
                            "802.11ac"
                        ]
                    }
                }
            }
        },
        "ntp": {
            "type": "object",
            "title": "ntp settings",
            "additionalProperties": True,
            "properties": {
                "enabled": {
                    "type": "boolean"
                },
                "enable_server": {
                    "type": "boolean"
                },
                "server": {
                    "type": "array"
                }
            }
        },
        "ip_rules": {
            "type": "array",
            "title": "Ip rules",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Ip rule",
                "additionalProperties": True,
                "properties": {
                    "in": {
                        "type": "string"
                    },
                    "out": {
                        "type": "string"
                    },
                    "src": {
                        "type": "string"
                    },
                    "dest": {
                        "type": "string"
                    },
                    "tos": {
                        "type": "integer"
                    },
                    "mark": {
                        "type": "string"
                    },
                    "invert": {
                        "type": "boolean",
                        "default": False
                    },
                    "lookup": {
                        "type": "string"
                    },
                    "goto": {
                        "type": "integer"
                    },
                    "action": {
                        "type": "string",
                        "enum": [
                            "prohibit",
                            "unreachable",
                            "blackhole",
                            "throw"
                        ]
                    }
                }
            }
        },
        "led": {
            "type": "array",
            "title": "LED config",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "LED",
                "additionalProperties": True,
                "required": [
                    "name",
                    "sysfs",
                    "trigger"
                ],
                "properties": {
                    "name": {
                        "type": "string"
                    },
                    "default": {
                        "type": "boolean"
                    },
                    "dev": {
                        "type": "string"
                    },
                    "sysfs": {
                        "type": "string"
                    },
                    "trigger": {
                        "type": "string"
                    },
                    "delayoff": {
                        "type": "integer"
                    },
                    "delayon": {
                        "type": "integer"
                    },
                    "interval": {
                        "type": "integer"
                    },
                    "message": {
                        "type": "string"
                    },
                    "mode": {
                        "type": "string"
                    }
                }
            }
        },
        "switch": {
            "type": "array",
            "title": "VLANs",
            "uniqueItems": True,
            "additionalItems": True,
            "title": "Programmable Switch",
            "items": {
                "type": "object",
                "additionalProperties": True,
                "required": [
                    "name",
                    "reset",
                    "enable_vlan",
                    "vlan"
                ],
                "properties": {
                    "name": {
                        "type": "string"
                    },
                    "reset": {
                        "type": "boolean"
                    },
                    "enable_vlan": {
                        "type": "boolean"
                    },
                    "vlan": {
                        "type": "array",
                        "title": "VLANs",
                        "uniqueItems": True,
                        "additionalItems": True,
                        "items": {
                            "type": "object",
                            "title": "VLAN",
                            "additionalProperties": True,
                            "required": [
                                "device",
                                "vlan",
                                "ports"
                            ],
                            "properties": {
                                "device": {
                                    "type": "string"
                                },
                                "vlan": {
                                    "type": "integer"
                                },
                                "ports": {
                                    "type": "string"
                                }
                            }
                        }
                    }
                }
            }
        },
        "files": {
            "type": "array",
            "title": "files",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "file",
                "additionalProperties": False,
                "required": [
                    "path",
                    "contents"
                ],
                "properties": {
                    "path": {
                        "type": "string"
                    },
                    "contents": {
                        "anyOf": [
                            {"type": "string", "format": "textarea"},
                            {"type": "array"}
                        ]
                    }
                }
            }
        }
    }
})
